@@ -1970,7 +1970,7 @@ int rktio_udp_set_receive_buffer_size(rktio_t *rktio, rktio_fd_t *rfd, int size)
 int rktio_udp_get_multicast_loopback(rktio_t *rktio, rktio_fd_t *rfd)
 {
   rktio_socket_t s = rktio_fd_socket(rktio, rfd);
-  u_char loop;
+  unsigned char loop;
   rktio_sockopt_len_t loop_len = sizeof(loop);
   int status;
   
@@ -1986,7 +1986,7 @@ int rktio_udp_get_multicast_loopback(rktio_t *rktio, rktio_fd_t *rfd)
 int rktio_udp_set_multicast_loopback(rktio_t *rktio, rktio_fd_t *rfd, int on)
 {
   rktio_socket_t s = rktio_fd_socket(rktio, rfd);
-  u_char loop = (on ? 1 : 0);
+  unsigned char loop = (on ? 1 : 0);
   rktio_sockopt_len_t loop_len = sizeof(loop);
   int status;
   
@@ -2034,7 +2034,7 @@ int rktio_udp_set_ttl(rktio_t *rktio, rktio_fd_t *rfd, int ttl_val)
 int rktio_udp_get_multicast_ttl(rktio_t *rktio, rktio_fd_t *rfd)
 {
   rktio_socket_t s = rktio_fd_socket(rktio, rfd);
-  u_char ttl;
+  unsigned char ttl;
   rktio_sockopt_len_t ttl_len = sizeof(ttl);
   int status;
   
@@ -2050,7 +2050,7 @@ int rktio_udp_get_multicast_ttl(rktio_t *rktio, rktio_fd_t *rfd)
 int rktio_udp_set_multicast_ttl(rktio_t *rktio, rktio_fd_t *rfd, int ttl_val)
 {
   rktio_socket_t s = rktio_fd_socket(rktio, rfd);
-  u_char ttl = ttl_val;
+  unsigned char ttl = ttl_val;
   rktio_sockopt_len_t ttl_len = sizeof(ttl);
   int status;
   
